py: library with cross-python path, ini-parsing, io, code, log facilities
=========================================================================

Description
-----------

library with cross-python path, ini-parsing, io, code, log facilities

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/py/

